@@ -3,8 +3,10 @@ from lftk.derivation.avgworddiff import AvgWordDiff
 from lftk.derivation.avgentity   import AvgEntity
 from lftk.derivation.typetokenratio import TypeTokenRatio
 from lftk.derivation.avgpartofspeech import AvgPartOfSpeech
+from lftk.derivation.lexicalvariation import LexicalVariation
 from lftk.derivation.readformula import ReadFormula
 from lftk.derivation.readtimeformula import ReadTimeFormula
 
-class DerivationCollector(AvgWordSent, AvgWordDiff, AvgEntity, TypeTokenRatio, AvgPartOfSpeech, ReadFormula, ReadTimeFormula):
+
+class DerivationCollector(AvgWordSent, AvgWordDiff, AvgEntity, TypeTokenRatio, AvgPartOfSpeech, ReadFormula, ReadTimeFormula, LexicalVariation):
     pass 
\ No newline at end of file
